# onlinepvt: Python SDK for accessing OnlinePVT API

[![PyPi](https://badge.fury.io/py/onlinepvt.svg)](https://pypi.org/project/onlinepvt/)

## Table of Contents

- [Overview](#overview)
- [Installation](#installation)
- [Supported Python Versions](#supported-python-versions)
- [License and Terms](#license-and-terms)

## Overview

[OnlinePVT](https://onlinepvt.com/) is the cloud version of VLXE.
It supports all the calculations and systems from the Excel version of VLXE but also much more.
The OnlinePVT Python SDK enables access to OnlinePVT services from privileged environments
(such as servers or cloud) in Python.

For more information, visit the [OnlinePVT product guide](https://onlinepvt.com/productguide).

## Installation

OnlinePvt Python SDK releases are available as wheel packages for macOS, Windows and Linux on PyPI. Install it using `pip <https://pypi.org/project/pip/>`\_:

```
pip install onlinepvt
pip install aiohttp
pip install matplotlib
pip install pytest-asyncio
```

## Supported Python Versions

We currently support Python 3.6+. OnlinePVT
Python SDK is also tested on PyPy environment.

## License and Terms

OnlinePVT Python SDK is licensed under the
[Apache License, version 2.0](http://www.apache.org/licenses/LICENSE-2.0).

Your use of OnlinePVT is governed by the
[Terms of Service for OnlinePVT](https://onlinepvt.com/).
